<?php
/**
 * Beispiel für eine Klasse, die Daten aus einem externen System liefert.
 *
 * In diesem Beispiel wird nicht wirklich ein externes System kontaktiert,
 * sondern lediglich einige Testdaten bereitgehalten, die zurückgeliefert werden.
 */
class GhExampleConnection
{
  /**
   * Kundendaten.
   * @var array
   */
  protected $customers = array(
    'K-12345' => array(
      'firstname' => 'Max',
      'lastname' => 'Mustermann',
      'customerNo' => 'K-12345',
      'email' => 'max@mustermann.de',
      'street' => 'Musterweg',
      'streetno' => '23',
      'zipcode' => '54321',
      'city' => 'Musterhausen',
      'country' => 'Deutschland'
    ),
    'K-34567' => array(
      'firstname' => 'Mona',
      'lastname' => 'Mustermann',
      'customerNo' => 'K-34567',
      'email' => 'mona@mustermann.de',
      'street' => 'Musterallee',
      'streetno' => '42',
      'zipcode' => '76543',
      'city' => 'Musterstadt',
      'country' => 'Deutschland'
    ),
  );

  /**
   * Bestelldaten.
   * @var array
   */
  protected $orders = array(
    'B-08109' => array(
      'orderNo' => 'B-08109',
      'orderDate' => '2011-09-12 18:24:05',
      'state' => 'open',
      'customerNo' => 'K-12345',
      'products' => array(
        array(
          'id' => 'A-42',
          'title' => 'Bleistift HB',
          'price' => 1.99,
          'amount' => 1,
          'total' => 1.99
        )
      ),
      'productsTotal' => 1.99,
      'shippingTotal' => 3.90,
      'orderTotal' => 5.98
    ),
    'B-10123' => array(
      'orderNo' => 'B-10123',
      'orderDate' => '2012-04-02 14:12:38',
      'state' => 'completed',
      'customerNo' => 'K-12345',
      'products' => array(
        array(
          'id' => 'A-456',
          'title' => 'Visitenkarten',
          'price' => 2.99,
          'amount' => 4,
          'total' => 11.96
        ),
        array(
          'id' => 'A-2323',
          'title' => 'Briefpapier',
          'price' => 6.99,
          'amount' => 3,
          'total' => 20.97
        ),
        array(
          'id' => 'A-42',
          'title' => 'Bleistift HB',
          'price' => 1.99,
          'amount' => 10,
          'total' => 19.9
        )
      ),
      'productsTotal' => 52.83,
      'shippingTotal' => 3.90,
      'orderTotal' => 56.73,
    ),
    'B-10131' => array(
      'orderNo' => 'B-10131',
      'orderDate' => '2012-04-12 19:01:22',
      'state' => 'open',
      'customerNo' => 'K-34567',
      'products' => array(
        array(
          'id' => 'A-456',
          'title' => 'Visitenkarten',
          'price' => 2.99,
          'amount' => 4,
          'total' => 11.96
        ),
        array(
          'id' => 'A-122',
          'title' => 'Füllfederhalter',
          'price' => 12.99,
          'amount' => 1,
          'total' => 12.99
        )
      ),
      'productsTotal' => 12.99,
      'shippingTotal' => 3.90,
      'orderTotal' => 16.89,
    )
  );

  /**
   * Liefert die Bestellungen eines Kunden anhand eines Suchbegriffs.
   *
   * @param string $searchTerm Suchbegriff
   * @return array
   */
  public function searchOrders($searchTerm)
  {

    foreach($this->orders as $order)
      if(stripos($order['orderNo'], $searchTerm) !== false)
        return $this->getOrders($order['customerNo']);

    foreach($this->customers as $customer)
      if(stripos($customer['customerNo'], $searchTerm) !== false
        || stripos($customer['firstname'], $searchTerm) !== false
        || stripos($customer['lastname'], $searchTerm) !== false
        || stripos($customer['email'], $searchTerm) !== false)
        return $this->getOrders($customer['customerNo']);

    return null;
  }

  /**
   * Liefert einen Kunden anhand der Kundennummer.
   *
   * @param string $customerNo Kundennummer
   * @return array
   */
  public function getCustomer($customerNo)
  {
    if(isset($this->customers[$customerNo]))
      return $this->customers[$customerNo];
    else
      return null;
  }

  /**
   * Liefert eine Bestellung anhand der Bestellnummer.
   *
   * @param string $orderNo Bestellnummer
   * @return array
   */
  public function getOrder($orderNo)
  {
    if(isset($this->orders[$orderNo]))
    {
      $order = $this->orders[$orderNo];
      $order['customer'] = $this->getCustomer($order['customerNo']);

      return $order;
    }
    else
      return null;
  }

  /**
   * Liefert alle Bestellungen eines Kunden, absteigend nach Bestelldatum sortiert.
   *
   * @param string $customerNo Kundennummer
   * @return array
   */
  public function getOrders($customerNo)
  {
    if(isset($this->customers[$customerNo]))
      $customer = $this->customers[$customerNo];
    else
      return null;

    $orders = array();
    $orderDates = array();

    foreach($this->orders as $order)
    {
      if($order['customerNo'] == $customerNo)
      {
        $order['customer'] = $customer;
        $orders[] = $order;
        $orderDates[] = strtotime($order['orderDate']);
      }
    }

    array_multisort($orders, SORT_DESC, $orderDates);

    return $orders;
  }
}
