<?php
// Einbinden der GREYHOUND PHP API (GUI):
require_once 'ghgui/ghgui.php';

// Ordner "core" zum Autoloader hinzufügen:
GhGui::addAutoLoadPath(dirname(__FILE__) . '/core');

// Webseite erzeugen:
$page = new GhGuiExtensionPage('Beispiel-Fenster (Details)');

// Layout für Toolbar (Oben) und Rest (Mitte):
$outerLayout = new GhGuiBorderContainer();
$page->addComponent($outerLayout);

// Layout für Liste mit Bestellungen (Oben) und IFrame (Mitte):
$innerLayout = new GhGuiBorderContainer(GhGuiBorderContainer::LAYOUT_HEADLINE, true);
$outerLayout->addCenterComponent($innerLayout);

// IFrame zur Darstellung von Details zur ausgewählten Bestellung:
$iframe = new GhGuiIframe('detailsiframe.php');
$innerLayout->addCenterComponent($iframe);

// Formatierer für Datumsangaben und Preise in der Liste:
$dateFormatter = new GhGuiFormatterDate(GhGuiFormatterDate::DATETIME_GERMAN);
$currencyFormatter = new GhGuiFormatterCurrency(2, ',', null, ' &euro;');

// Liste der Bestellungen:
// Beim Anklicken einer Bestellung wird deren Bestellnummer an das IFrame übermittelt,
// welches dann die Bestelldetails darstellt.
$ordersForm = new GhGuiForm('detailsiframe.php');
$ordersForm->setTarget($iframe);
$innerLayout->addTopComponent($ordersForm, '40%');
$ordersList = new GhGuiDataGrid('order', GhGuiDataGrid::SELECTION_SINGLE, true, 'orderNo');
$ordersList->setWidgetProperty('selectable', true); // Text in der Liste auswählbar machen
$ordersList->addColumn('orderDate', 'Datum', null, $dateFormatter);
$ordersList->addColumn('orderNo', 'Bestellnr');
$ordersList->addColumn('state', 'Status');
$ordersList->addColumn('productsTotal', 'Artikel', null, $currencyFormatter);
$ordersList->addColumn('shippingTotal', 'Versand', null, $currencyFormatter);
$ordersList->addColumn('orderTotal', 'Gesamt', null, $currencyFormatter);
$ordersForm->addComponent($ordersList);

// Daten des aktuellen Elements:
$email = trim(GhCoreGlobals::getValue('email'));
$search = trim(GhCoreGlobals::getValue('search'));

if(strlen($search) == 0)
  $search = $email;

// Bestelldaten abrufen:
$connection = new GhExampleConnection();
$orders = $connection->searchOrders($search);

if(is_array($orders) && !empty($orders))
{
  // Sicherstellen, dass das Datumsformat für Javascript gültig ist:
  foreach($orders as $key => $order)
    $orders[$key]['orderDate'] = date('r', strtotime($order['orderDate']));

  // Bestellungen zur Liste hinzufügen:
  $ordersList->addRows($orders);

  // Erste Bestellung vorauswählen:
  $ordersList->setValue($orders[0]['orderNo']);
  $iframe->setUrl('detailsiframe.php?order=' . $orders[0]['orderNo']);
}

// Toolbar:
$toolbar = new GhGuiToolbar();
$outerLayout->addTopComponent($toolbar);

// Suchfeld:
$searchForm = new GhGuiForm();
$toolbar->addComponent($searchForm);
$searchField = new GhGuiTextBox('search', $search);
$searchForm->addComponent($searchField);

// Webseite anzeigen:
$page->show();
