<?php
// Einbinden der GREYHOUND PHP API (GUI):
require_once 'ghgui/ghgui.php';

// Ordner "core" zum Autoloader hinzufügen:
GhGui::addAutoLoadPath(dirname(__FILE__) . '/core');

// Webseite erzeugen:
$page = new GhGuiExtensionPage('Beispiel-Fenster (Details)');

// Formular (notwendig für die DataGrids):
$form = new GhGuiForm();
$page->addComponent($form);

// Layout: Liste mit Adressdaten (Links) und Liste mit Artikeln (Rechts):
$layout = new GhGuiBorderContainer(GhGuiBorderContainer::LAYOUT_SIDEBAR, true);
$form->addComponent($layout);

// Liste für die Adressangaben:
$addressData = new GhGuiDataGrid();
$addressData->setWidgetProperty('selectable', true); // Text in der Liste auswählbar machen
$addressData->addColumn('key', 'Feld');
$addressData->addColumn('value', 'Wert');
$layout->addLeftComponent($addressData, '40%');

// Formatierer für Preise in der Artikelliste:
$currencyFormatter = new GhGuiFormatterCurrency(2, ',', null, ' &euro;');

// Artikelliste:
$productData = new GhGuiDataGrid();
$productData->setWidgetProperty('selectable', true); // Text in der Liste auswählbar machen
$productData->addColumn('amount', 'Anzahl');
$productData->addColumn('id', 'Artikelnr');
$productData->addColumn('title', 'Bezeichnung');
$productData->addColumn('price', 'Einzelpreis', null, $currencyFormatter);
$productData->addColumn('total', 'Gesamtpreis', null, $currencyFormatter);
$layout->addCenterComponent($productData);

// Bestelldaten:
$orderNo = GhCoreGlobals::getValue('order');

if($orderNo)
{
  // Bestelldaten abrufen:
  $connection = new GhExampleConnection();
  $order = $connection->getOrder($orderNo);

  if($order)
  {
    // Artikel zur Liste hinzufügen:
    $productData->addRows($order['products']);

    // Adressangaben zur Liste hinzufügen:
    if(isset($order['customer']) && !empty($order['customer']))
    {
      $customer = $order['customer'];
      $addressData->addRow(array('key' => 'Kundennr', 'value' => $customer['customerNo']));
      $addressData->addRow(array('key' => 'Vorname', 'value' => $customer['firstname']));
      $addressData->addRow(array('key' => 'Nachname', 'value' => $customer['lastname']));
      $addressData->addRow(array('key' => 'Straße', 'value' => $customer['street'] . ' ' . $customer['streetno']));
      $addressData->addRow(array('key' => 'Stadt', 'value' => $customer['zipcode'] . ' ' . $customer['city']));
      $addressData->addRow(array('key' => 'Land', 'value' => $customer['country']));
    }
  }
}

// Webseite anzeigen:
$page->show();
