<?php
// Einbinden der GREYHOUND PHP API (GUI und RPC):
require_once 'ghgui/ghgui.php';
require_once 'ghrpc/ghrpc.php';

// Ordner "core" zum Autoloader hinzufügen:
GhGui::addAutoLoadPath(dirname(__FILE__) . '/core');

// Webseite erzeugen:
$page = new GhGuiExtensionPage('Beispiel-Fenster (Details)');
$page->setStyle('overflow', 'hidden');

// Daten des aktuellen Elements:
$email = trim(GhCoreGlobals::getValue('email'));
$search = trim(GhCoreGlobals::getValue('search'));
$itemId = GhCoreGlobals::getValue('item');
$subject = trim(GhCoreGlobals::getValue('subject'));

if(strlen($search) == 0)
  $search = $email;

// Kundendaten und Bestellung abrufen:
$order = null;
$customer = null;

if(strlen($search) > 0)
{
  $connection = new GhExampleConnection();
  $orders = $connection->searchOrders($search);

  if(is_array($orders) && !empty($orders))
  {
    $order = $orders[0];

    if(isset($order['customer']) && !empty($order['customer']))
      $customer = $order['customer'];
  }
}

// Verbindung zum GREYHOUND Server vorbereiten:
$ghHost = GhCoreGlobals::getValue('ghhost');
$ghPort = GhCoreGlobals::getValue('ghport');
$ghProtocol = GhCoreGlobals::getValue('ghprotocol');
$ghToken = GhCoreGlobals::getValue('ghtoken');

if($ghHost && $ghPort && $ghProtocol && $ghToken)
  $ghClient = new GhRpcClient($ghHost, $ghPort, $ghProtocol == 'https', 'token', $ghToken);
else
  $ghClient = null;

// Layout:
$layout1 = new GhGuiBorderContainer();
$page->addComponent($layout1);

$layout2 = new GhGuiBorderContainer();
$layout1->addCenterComponent($layout2);

// Suchfeld:
$searchField = new GhGuiTextBox('search');
$searchField->setValue($search);
$searchField->setFillWidth(true);
$searchForm = new GhGuiForm();
$searchForm->addComponent($searchField);
$searchForm->addHiddenField('ghhost', $ghHost);
$searchForm->addHiddenField('ghport', $ghPort);
$searchForm->addHiddenField('ghprotocol', $ghProtocol);
$searchForm->addHiddenField('ghtoken', $ghToken);
$searchForm->setStyle('padding', '8px');
$searchForm->setStyle('margin-bottom', '6px');
$searchForm->setStyle('background', '#afafaf');
$searchForm->setStyle('border-bottom', '1px solid #4c4c4c');
$layout1->addTopComponent($searchForm, '21px');

// E-Mail Funktionen und Textbausteine:
if($customer && $customer['email'] && $ghClient)
{
  // Formular für die E-Mail Funktionen:
  // Ein neuer Tab im GREYHOUND Client wird über die URL "greyhound:NewItem"
  // (oder "greyhound:AnswerItem", usw.) erzeugt. Die URL "greyhound:" löst
  // eine sogenannte WM_COPYDATA Funktion im GREYHOUND Client aus.
  // Die Buttons setzen in diesem Formular die benötigten Werte, bevor sie das
  // Formular absenden (per Javascript).
  // Siehe: http://greyhound-software.com/docs/manual/texts/63_Erstellen_von_Elementen
  $emailActionsForm = new GhGuiForm('greyhound:NewItem', 'get');
  $emailActionsForm->addHiddenField('Kind', 'EMail');
  $emailActionsForm->addHiddenField('Recipients[0]', $customer['email']);
  $emailActionsForm->addHiddenField('ItemID', $itemId);
  $emailActionsForm->setStyle('margin-bottom', '6px');
  $emailActionsForm->setStyle('border-top', '1px solid #4c4c4c');
  $emailActionsForm->setStyle('border-bottom', '1px solid #4c4c4c');
  $emailActionsSubjectField = $emailActionsForm->addHiddenField('Subject', '');
  $emailActionsFormVar = $emailActionsForm->getJavascriptWidgetVariable();
  $layout2->addTopComponent($emailActionsForm, '70px');

  // Formular für E-Mail Funktionen:
  $emailActions = new GhGuiBorderContainer();
  $emailActions->setStyle('padding', '8px');
  $emailActions->setStyle('background', '#afafaf');
  $emailActionsForm->addComponent($emailActions);

  // Textbausteine vom GREYHOUND Server abrufen und auswählbar machen:
  try
  {
    $textBlocks = new GhRpcTree(rpc_textblockslib::newRpcTextBlocks($ghClient)->GetList(false));
    $textBlockField = new GhGuiComboTree('TextBlockID', $textBlocks);
    $textBlockField->setStyle('margin-bottom', '7px');
    $emailActions->addCenterComponent($textBlockField);
  }
  catch(Exception $exception)
  {
    $textBlocks = null;
  }

  // Funktion "Neue E-Mail":
  $newEmailButton = new GhGuiButton('Neue E-Mail', false);
  $newEmailButton->addEventHandler(GhGuiEvent::EVENT_CLICK, new GhGuiEventJavascript('function(){' .
    $emailActionsFormVar . '.action="greyhound:NewItem";' .
    $emailActionsSubjectField->getJavascriptWidgetVariable() . '.value="";' .
    $emailActionsFormVar . '.submit();' .
  '}'));

  // Funktion "Antworten":
  $replyEmailButton = new GhGuiButton('Antworten', false);
  $replyEmailButton->setStyle('margin-left', '5px');
  $replyEmailButton->addEventHandler(GhGuiEvent::EVENT_CLICK, new GhGuiEventJavascript('function(){' .
    $emailActionsFormVar . '.action="greyhound:AnswerItem";' .
    $emailActionsSubjectField->getJavascriptWidgetVariable() . '.value="Re: ' . str_replace('"', '\\"', $subject) . '";' .
    $emailActionsFormVar . '.submit();' .
  '}'));

  // Buttons hinzufügen:
  $emailActions->addBottomComponent(new GhGuiPanel($newEmailButton, $replyEmailButton));

  // Falls kein Element ausgewählt ist wird der "Antworten"-Button deaktiviert:
  if(!$itemId)
    $replyEmailButton->setDisabled(true);
}

// Info zu Kunde und Bestellung:
$info = new GhGuiText();
$info->setStyle('background', '#afafaf');
$info->setStyle('padding', '6px');
$info->setStyle('border-top', '1px solid #4c4c4c');
$layout2->addCenterComponent($info);

if($order)
{
  $info->addText('<table style="border:0;">');
  $info->addText('<tr><td><strong>KdNr:</strong></td><td>' . $order['customerNo'] . '</td></tr>');

  if($customer)
  {
    $info->addText('<tr><td><strong>Name:</strong></td><td>' . $customer['firstname'] . ' ' . $order['customer']['lastname'] . '</td></tr>');
    $info->addText('<tr><td style="vertical-align:top;"><strong>Adresse:</strong></td><td>');
    $info->addText($customer['street'] . ' ' . $customer['streetno'])->addLineBreak();
    $info->addText($customer['zipcode'] . ' ' . $customer['city'])->addLineBreak();
    $info->addText($customer['country']);
    $info->addText('</td></tr>');
    $info->addText('<tr><td>&nbsp;</td><td>&nbsp;</td></tr>');
  }

  $info->addText('<tr><td><strong>BestNr:</strong></td><td>' . $order['orderNo'] . '</td></tr>');
  $info->addText('<tr><td><strong>Datum:</strong></td><td>' . date('d.m.Y H:i:s', strtotime($order['orderDate'])) . '</td></tr>');
  $info->addText('<tr><td><strong>Betrag:</strong></td><td>' . str_replace('.', ',', sprintf('%.02f', $order['orderTotal'])) . ' &euro;</td></tr>');
  $info->addText('<tr><td><strong>Status:</strong></td><td>' . $order['state']);
  $info->addText('</table>');

  if(isset($order['products']) && !empty($order['products']))
  {
    $info->addLineBreak();
    $info->addText('<strong>Produkte:</strong>');
    $info->addText('<table style="border:0;">');
    $info->addText('<tr><th>Anzahl</th><th>ArtNr</th><th>Bezeichnung</th><th>Einzel</th><th>Gesamt</th></tr>');

    foreach($order['products'] as $product)
    {
      $info->addText('<tr>' .
        '<td>' . $product['amount'] . '</td>' .
        '<td>' . $product['id'] . '</td>' .
        '<td>' . $product['title'] . '</td>' .
        '<td>' . str_replace('.', ',', sprintf('%.02f', $product['price'])) . ' &euro;</td>' .
        '<td>' . str_replace('.', ',', sprintf('%.02f', $product['total'])) . ' &euro;</td>' .
        '</tr>');
    }

    $info->addText('</table>');
  }
}
else
  $info->addText('Keine Daten gefunden.');

// Webseite anzeigen:
$page->show();
